@@ -2,32 +2,9 @@
     models/keylistsortfilterproxymodel.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "keylistsortfilterproxymodel.h"
@@ -40,6 +17,10 @@
 
 #include <gpgme++/key.h>
 
+#include <gpgme++/gpgmepp_version.h>
+#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
+# define GPGME_HAS_REMARKS
+#endif
 
 using namespace Kleo;
 using namespace GpgME;
@@ -98,7 +79,7 @@ QModelIndex AbstractKeyListSortFilterProxyModel::index(const Key &key) const
     if (const KeyListModelInterface *const klmi = dynamic_cast<KeyListModelInterface *>(sourceModel())) {
         return mapFromSource(klmi->index(key));
     } else {
-        return QModelIndex();
+        return {};
     }
 }
 
@@ -161,7 +142,7 @@ void KeyListSortFilterProxyModel::setKeyFilter(const std::shared_ptr<const KeyFi
         return;
     }
     d->keyFilter = kf;
-    invalidateFilter();
+    invalidate();
 }
 
 bool KeyListSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
@@ -203,6 +184,17 @@ bool KeyListSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelI
                 match = true;
                 break;
             }
+#ifdef GPGME_HAS_REMARKS
+            // Also match against remarks (search tags)
+            const auto alm = dynamic_cast<AbstractKeyListModel *>(sourceModel());
+            if (alm) {
+                const auto remarks = alm->data(alm->index(key, KeyListModelInterface::Remarks));
+                if (!remarks.isNull() && remarks.toString().contains(rx)) {
+                    match = true;
+                    break;
+                }
+            }
+#endif
         }
         if (!match) {
             return false;
