@@ -2,32 +2,9 @@
     newkeyapprovaldialog.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2018 Intevation GmbH
+    SPDX-FileCopyrightText: 2018 Intevation GmbH
 
-    Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.
-
-    Libkleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "newkeyapprovaldialog.h"
@@ -628,7 +605,13 @@ public:
             }
         }
 
-        mOkButton->setEnabled(!isAllIgnored);
+        // If we don't encrypt the ok button is always enabled. But otherwise
+        // we only enable it if we encrypt to at least one recipient.
+        if (!mEncCombos.size()) {
+            mOkButton->setEnabled(true);
+        } else {
+            mOkButton->setEnabled(!isAllIgnored);
+        }
 
         if (!isGenerate) {
             mOkButton->setText(origOkText);
@@ -640,21 +623,40 @@ public:
 
         // Handle compliance
         bool de_vs = true;
-        for (const auto &key: q->signingKeys()) {
+
+        bool isPGP = mFormatBtns->checkedId() == 1;
+        bool isSMIME = mFormatBtns->checkedId() == 2;
+
+        for (const auto combo: qAsConst(mEncCombos)) {
+            const auto &key = combo->currentKey();
+            if (!combo->isVisible()) {
+                continue;
+            }
+            if (isSMIME && key.protocol() != GpgME::CMS) {
+                continue;
+            }
+            if (isPGP && key.protocol() != GpgME::OpenPGP) {
+                continue;
+            }
             if (!Formatting::isKeyDeVs(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
                 de_vs = false;
                 break;
             }
         }
         if (de_vs) {
-            for (const auto &keys: q->encryptionKeys().values()) {
-                for (const auto &key: keys) {
-                    if (!Formatting::isKeyDeVs(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
-                        de_vs = false;
-                        break;
-                    }
+            for (const auto combo: qAsConst(mSigningCombos)) {
+                const auto key = combo->currentKey();
+                if (!combo->isVisible()) {
+                    continue;
                 }
-                if (!de_vs) {
+                if (isSMIME && key.protocol() != GpgME::CMS) {
+                    continue;
+                }
+                if (isPGP && key.protocol() != GpgME::OpenPGP) {
+                    continue;
+                }
+                if (!Formatting::isKeyDeVs(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
+                    de_vs = false;
                     break;
                 }
             }
@@ -667,10 +669,10 @@ public:
                     ? QStringLiteral("#D5FAE2")  // KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color().name()
                     : QStringLiteral("#FAE9EB"))); //KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color().name()));
         mComplianceLbl->setText(de_vs
-                ? i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
-                    "VS-NfD-compliant communication possible.")
-                : i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
-                    "VS-NfD-compliant communication not possible."));
+                ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
+                    "%1 communication possible.", Formatting::deVsString())
+                : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
+                    "%1 communication not possible.", Formatting::deVsString()));
         mComplianceLbl->setVisible(true);
     }
 
