@@ -3,36 +3,14 @@
     utils/formatting.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "formatting.h"
 #include "kleo/dn.h"
+#include "kleo/keyfiltermanager.h"
 
 #include <gpgme++/key.h>
 #include <gpgme++/importresult.h>
@@ -49,14 +27,9 @@
 #include <QTextDocument> // for Qt::escape
 #include <QLocale>
 #include <QIcon>
-#include <QColor>
 #include <QRegularExpression>
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION > 0x10900
-# define GPGME_HAS_KEY_IS_DEVS
-#endif
-
+#include "models/keycache.h"
 
 using namespace GpgME;
 using namespace Kleo;
@@ -291,7 +264,7 @@ QString format_keyusage(const Key &key)
     if (key.canAuthenticate()) {
         capabilities.push_back(i18n("SSH Authentication"));
     }
-    return capabilities.join(QStringLiteral(", "));
+    return capabilities.join(QLatin1String(", "));
 }
 
 QString format_subkeyusage(const Subkey &subkey)
@@ -313,7 +286,7 @@ QString format_subkeyusage(const Subkey &subkey)
     if (subkey.canAuthenticate()) {
         capabilities.push_back(i18n("SSH Authentication"));
     }
-    return capabilities.join(QStringLiteral(", "));
+    return capabilities.join(QLatin1String(", "));
 }
 
 static QString time_t2string(time_t t)
@@ -388,7 +361,7 @@ QString Formatting::toolTip(const Key &key, int flags)
                                  ? i18n("Subject")
                                  : i18n("User-ID"), prettyUserID(uids.front()));
         if (uids.size() > 1)
-            for (std::vector<UserID>::const_iterator it = uids.begin() + 1, end = uids.end(); it != end; ++it)
+            for (auto it = uids.begin() + 1, end = uids.end(); it != end; ++it)
                 if (!it->isRevoked() && !it->isInvalid()) {
                     result += format_row(i18n("a.k.a."), prettyUserID(*it));
                 }
@@ -479,7 +452,7 @@ namespace
 static QDate time_t2date(time_t t)
 {
     if (!t) {
-        return QDate();
+        return {};
     }
     QDateTime dt;
     dt.setTime_t(t);
@@ -507,6 +480,11 @@ QDate expiration_date(const T &tee)
 }
 }
 
+QString Formatting::dateString(time_t t)
+{
+    return date2string(time_t2date(t));
+}
+
 QString Formatting::expirationDateString(const Key &key)
 {
     return expiration_date_string(key.subkey(0));
@@ -574,7 +552,7 @@ QDate Formatting::creationDate(const UserID::Signature &sig)
 QString Formatting::displayName(Protocol p)
 {
     if (p == CMS) {
-        return i18nc("X.509/CMS encryption standard", "X.509");
+        return i18nc("X.509/CMS encryption standard", "S/MIME");
     }
     if (p == OpenPGP) {
         return i18n("OpenPGP");
@@ -678,7 +656,22 @@ QString Formatting::validityShort(const UserID::Signature &sig)
     case UserID::Signature::SigExpired:   return i18n("expired");
     case UserID::Signature::KeyExpired:   return i18n("certificate expired");
     case UserID::Signature::BadSignature: return i18nc("fake/invalid signature", "bad");
-    case UserID::Signature::NoPublicKey:  return i18n("no public key");
+    case UserID::Signature::NoPublicKey: {
+            /* GnuPG returns the same error for no public key as for expired
+             * or revoked certificates. */
+            const auto key = KeyCache::instance()->findByKeyIDOrFingerprint (sig.signerKeyID());
+            if (key.isNull()) {
+                return i18n("no public key");
+            } else if (key.isExpired()) {
+                return i18n("key expired");
+            } else if (key.isRevoked()) {
+                return i18n("key revoked");
+            } else if (key.isDisabled()) {
+                return i18n("key disabled");
+            }
+            /* can't happen */
+            return QStringLiteral("unknown");
+        }
     }
     return QString();
 }
@@ -883,7 +876,7 @@ QString Formatting::usageString(const Subkey &sub)
     if (sub.canAuthenticate()) {
         usageStrings << i18n("Authenticate");
     }
-    return usageStrings.join(QStringLiteral(", "));
+    return usageStrings.join(QLatin1String(", "));
 }
 
 QString Formatting::summaryLine(const Key &key)
@@ -958,7 +951,7 @@ QString Formatting::complianceMode()
     }
     const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Configuration"), QStringLiteral("compliance"));
 
-    if (!entry || entry->stringValue() == QStringLiteral("gnupg")) {
+    if (!entry || entry->stringValue() == QLatin1String("gnupg")) {
         return QString();
     }
     return entry->stringValue();
@@ -966,7 +959,6 @@ QString Formatting::complianceMode()
 
 bool Formatting::isKeyDeVs(const GpgME::Key &key)
 {
-#ifdef GPGME_HAS_KEY_IS_DEVS
     for (const auto &sub: key.subkeys()) {
         if (sub.isExpired() || sub.isRevoked()) {
             // Ignore old subkeys
@@ -977,22 +969,19 @@ bool Formatting::isKeyDeVs(const GpgME::Key &key)
         }
     }
     return true;
-#else
-    return false;
-#endif
 }
 
 QString Formatting::complianceStringForKey(const GpgME::Key &key)
 {
     // There will likely be more in the future for other institutions
     // for now we only have DE-VS
-    if (complianceMode() == QStringLiteral("de-vs")) {
+    if (complianceMode() == QLatin1String("de-vs")) {
         if (uidsHaveFullValidity(key) && isKeyDeVs(key)) {
-            return i18nc("VS-NfD conforming is a German standard for restricted documents. For which special restrictions about algorithms apply. The string describes if a key is compliant with that..",
-                         "May be used for VS-NfD-compliant communication.");
+            return i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
+                         "May be used for %1 communication.", deVsString());
         } else {
             return i18nc("VS-NfD-conforming is a German standard for restricted documents. For which special restrictions about algorithms apply. The string describes if a key is compliant to that..",
-                         "May <b>not</b> be used for VS-NfD-compliant communication.");
+                         "May <b>not</b> be used for %1 communication.", deVsString());
         }
     }
     return QString();
@@ -1001,17 +990,24 @@ QString Formatting::complianceStringForKey(const GpgME::Key &key)
 QString Formatting::complianceStringShort(const GpgME::Key &key)
 {
     if (Formatting::uidsHaveFullValidity(key)) {
-        if (complianceMode() == QStringLiteral("de-vs")
+        if (complianceMode() == QLatin1String("de-vs")
             && Formatting::isKeyDeVs(key)) {
-            return QStringLiteral("★ ") +
-                i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a key is compliant with that.",
-                      "VS-NfD-compliant");
+            return QStringLiteral("★ ") + deVsString(true);
         }
         return i18nc("As in all user IDs are valid.", "certified");
     }
     if (key.isExpired()) {
         return i18n("expired");
     }
+    if (key.isRevoked()) {
+        return i18n("revoked");
+    }
+    if (key.isDisabled()) {
+        return i18n("disabled");
+    }
+    if (key.isInvalid()) {
+        return i18n("invalid");
+    }
 
     return i18nc("As in not all user IDs are valid.", "not certified");
 }
@@ -1021,5 +1017,45 @@ QString Formatting::prettyID(const char *id)
     if (!id) {
         return QString();
     }
-    return QString::fromLatin1(id).toUpper().replace(QRegularExpression(QStringLiteral("(....)")), QStringLiteral("\\1 ")).trimmed();
+    QString ret = QString::fromLatin1(id).toUpper().replace(QRegularExpression(QStringLiteral("(....)")),
+                                                            QStringLiteral("\\1 ")).trimmed();
+    // For the standard 10 group fingerprint let us use a double space in the
+    // middle to increase readability
+    if (ret.size() == 49) {
+        ret.insert(24, QLatin1Char(' '));
+    }
+    return ret;
+}
+
+QString Formatting::origin(int o)
+{
+    switch (o) {
+        case Key::OriginKS:
+            return i18n("Keyserver");
+        case Key::OriginDane:
+            return QStringLiteral("DANE");
+        case Key::OriginWKD:
+            return QStringLiteral("WKD");
+        case Key::OriginURL:
+            return QStringLiteral("URL");
+        case Key::OriginFile:
+            return i18n("File import");
+        case Key::OriginSelf:
+            return i18n("Generated");
+        case Key::OriginOther:
+        case Key::OriginUnknown:
+        default:
+          return i18n("Unknown");
+    }
+}
+
+QString Formatting::deVsString(bool compliant)
+{
+    const auto filter = KeyFilterManager::instance()->keyFilterByID(compliant ?
+            QStringLiteral("de-vs-filter") :
+            QStringLiteral("not-de-vs-filter"));
+    if (!filter) {
+        return compliant ? i18n("VS-NfD compliant") : i18n("Not VS-NfD compliant");
+    }
+    return filter->name();
 }
